summaryrefslogtreecommitdiff
path: root/firmware/lib/cgptlib/include/cgptlib_internal.h
diff options
context:
space:
mode:
Diffstat (limited to 'firmware/lib/cgptlib/include/cgptlib_internal.h')
-rw-r--r--firmware/lib/cgptlib/include/cgptlib_internal.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/firmware/lib/cgptlib/include/cgptlib_internal.h b/firmware/lib/cgptlib/include/cgptlib_internal.h
index cc01f4ca..10ffa392 100644
--- a/firmware/lib/cgptlib/include/cgptlib_internal.h
+++ b/firmware/lib/cgptlib/include/cgptlib_internal.h
@@ -129,11 +129,11 @@ int HeaderFieldsSame(GptHeader *h1, GptHeader *h2);
*
* On error, returns a GPT_ERROR_* return code.
*/
-int GptSanityCheck(GptData *gpt);
+int GptValidityCheck(GptData *gpt);
/**
* Repair GPT data by copying from one set of valid headers/entries to the
* other. Assumes GptSanityCheck() has been run to determine which headers
* and/or entries are already valid.
*
* The caller must make sure that even if one of the entries table is invalid
@@ -129,11 +129,11 @@ int HeaderFieldsSame(GptHeader *h1, GptHeader *h2);
/**
* Repair GPT data by copying from one set of valid headers/entries to the
- * other. Assumes GptSanityCheck() has been run to determine which headers
+ * other. Assumes GptValidityCheck() has been run to determine which headers
* and/or entries are already valid.
*